@@ -2,12 +2,14 @@
     include  a multiple-line  comment
     in your code'''
 __author__ = 'qiuqiaohua'
-def print_lol(the_list):
+def print_lol(the_list,level):
     """
     递归输出列表的每个item
     """
     for each in the_list:
         if isinstance(each,list):
-            print_lol(each)
+            print_lol(each,level+1)
         else:
+            for num in range(level):
+                print("\t",end='')
             print(each)
\ No newline at end of file
